from flask import Blueprint, render_template, current_app, request, jsonify, session, flash, redirect, url_for, g
from velero.utils import velero

profile = Blueprint("restore_get", __name__)


@profile.route("/restore/get")
def index():
    listq = velero("restore get")
    # current_app.logger.error(f"Backup list: {list}")
    return jsonify(listq)



# import bjoern
# from velero import app

# host = '0.0.0.0'
# port = 8000
# bjoern.listen(app, host, port)
# bjoern.run()

from velero import app

if __name__ == '__main__':
    # import bjoern
    host = "0.0.0.0"
    port = 8000

    # bjoern.listen(app, host, port)
    # bjoern.run(statsd=...)
    app.run(host=host, port=port, debug=True)



from flask import Blueprint, jsonify
from velero.utils import velero

profile = Blueprint("settings", __name__)


@profile.route("/location/backup")
def backup():
    location = velero("backup-location get")
    # current_app.logger.error(f"Backup list: {list}")
    return jsonify(location)


@profile.route("/location/snapshot")
def snapshot():
    location = velero("snapshot-location get")
    # current_app.logger.error(f"Backup list: {list}")
    return jsonify(location)


from flask import Blueprint, render_template, current_app, request, jsonify, session, flash, redirect, url_for, g
from datetime import datetime
from velero.utils import velero

profile = Blueprint("backup_index", __name__)
date_format = "%Y-%m-%dT%H:%M:%SZ"


@profile.route("/backups", methods=["GET"])
def index():
    list = velero("backup get")

    backup_list = []
    backup_dict = {}

    if "items" in list:
        for item in list["items"]:
            backup_dict = {}
            for k, v in item.items():
                if k == "metadata":
                    for meta, mvalue in v.items():
                        if meta == "name":
                            backup_dict[meta] = mvalue
                        if meta == "creationTimestamp":
                            backup_dict[meta] = mvalue
                            c_time = datetime.strptime(mvalue, date_format)
                if k == "status":
                    for status, svalue in v.items():
                        if status == "phase" or status == "errors" or status == "warnings":
                            backup_dict[status] = svalue
                        if status == "expiration":
                            e_time = datetime.strptime(svalue, date_format)
                            delta = (e_time - c_time)
                            backup_dict[status] = f"{delta.days - 1}d"
                if k == "spec":
                    for spec, pvalue in v.items():
                        if spec == "storageLocation" or spec == "selector":
                            backup_dict[spec] = pvalue
            current_app.logger.error(f"dict {backup_dict}")
            backup_list.append(backup_dict)
        current_app.logger.error(f"key {backup_list}")
    else:
        for k, v in list.items():
            if k == "metadata":
                for meta, mvalue in v.items():
                    if meta == "name":
                        backup_dict[meta] = mvalue
                    if meta == "creationTimestamp":
                        backup_dict[meta] = mvalue
                        c_time = datetime.strptime(mvalue, date_format)
            if k == "status":
                for status, svalue in v.items():
                    if status == "phase" or status == "errors" or status == "warnings":
                        backup_dict[status] = svalue
                    if status == "expiration":
                        e_time = datetime.strptime(svalue, date_format)
                        delta = (e_time - c_time)
                        backup_dict[status] = f"{delta.days - 1}d"
            if k == "spec":
                for spec, pvalue in v.items():
                    if spec == "storageLocation" or spec == "selector":
                        backup_dict[spec] = pvalue

        backup_list.append(backup_dict)
    
    # current_app.logger.error(f"key {backup_list}")
    return render_template("backup/index.html", backups=backup_list, page="backup")



import os
import json

from uuid import uuid4


def gen_uuid():
    """
    Objetivo: Criar uuids.
    """
    uuid_str = str(uuid4())
    return uuid_str


def convert_days_to_sec(days):
    """
    Objetivo: Converter um numero em dias para formato em segundos.
    """
    seconds = int(days) * 86400
    return seconds


def velero(cmd):
    """
    Objetive: Run velero and get output json
    """
    run = os.popen(f"velero {cmd} -o json")
    return json.loads(run.read())

def velero_str(cmd):
    """
    Objetive: Run velero and get output text
    """
    run = os.popen(f"velero {cmd}")
    return run.read()



from flask import Blueprint, render_template, current_app, request, jsonify, session, flash, redirect, url_for, g
from velero.utils import velero_str

profile = Blueprint("backup_delete", __name__)


@profile.route("/backup/delete/<backup>", methods=["GET"])
def delete(backup):
    if request.method == "GET":
        str = velero_str(f"backup delete {backup} --confirm")
        if "submitted successfully" in str:
            flash(f"Backup successful delete", "success")
        else:
            flash(f"Backup cannot be deleted", "error")

    # current_app.logger.error(f"Backup list: {str}")
    return redirect(url_for('backup_index.index'))



from flask import Blueprint, render_template, current_app, request, jsonify, session, flash, redirect, url_for, g
from velero.utils import velero_str

profile = Blueprint("backup_logs", __name__)


@profile.route("/backup/logs/<backup>")
def logs(backup):
    str = velero_str(f"backup logs {backup}")
    # current_app.logger.error(f"Backup list: {list}")
    return str



from os import environ

from flask import Blueprint, redirect, url_for
# from flask_oidc import OpenIDConnect

profile = Blueprint("auth", __name__, url_prefix="/")
# oidc = OpenIDConnect()


# @profile.route("/login")
# @oidc.require_login
# def login():
#     """
#     Objetivo: Forcar o usuario a autenticar e com sucesso ira para o home.
#     """
#     return redirect(url_for("home.index"))


# @profile.route("/logout")
# def logout():
#     """
#     Objetivo: Efetuar logout.
#     """
#     oidc.logout()
#     return redirect(url_for("home.index"))



"""An amazing sample package!"""

__version__ = "0.1.1"

from flask import Flask, render_template
from logging.config import dictConfig
from velero.views import dashboard
from velero.views.settings import settings
from velero.views.backup import backup_index
from velero.views.backup import backup_get
from velero.views.backup import backup_describe
from velero.views.backup import backup_logs
from velero.views.backup import backup_delete
from velero.views.restore import restore_get
from velero.views.schedule import schedule_get

dictConfig({
    'version': 1,
    'formatters': {'default': {
        'format': '[%(asctime)s] %(levelname)s in %(module)s: %(message)s',
    }},
    'handlers': {'wsgi': {
        'class': 'logging.StreamHandler',
        'stream': 'ext://sys.stdout',
        'formatter': 'default'
    }},
    'root': {
        'level': 'INFO',
        'handlers': ['wsgi']
    }
})

app = Flask(__name__)

app.config.from_object("config")
app.config["SECRET_KEY"]

@app.errorhandler(404)
def not_found(error):
    return render_template("404.html"), 404


@app.errorhandler(403)
def insufficient_permissions(e):
    return render_template("403.html"), 403

app.register_blueprint(dashboard.profile)
app.register_blueprint(settings.profile)
app.register_blueprint(backup_index.profile)
app.register_blueprint(backup_get.profile)
app.register_blueprint(backup_describe.profile)
app.register_blueprint(backup_logs.profile)
app.register_blueprint(backup_delete.profile)
app.register_blueprint(restore_get.profile)
app.register_blueprint(schedule_get.profile)



import os

DEBUG = os.getenv("DEBUG", False)

BCRYPT_LOG_ROUNDS = 12

SECRET_KEY = "1b2ac321-c8fc-4ad5-a0ca-44ba12364618"

MAX_SESSION_TIME = 365

# MAIL_FROM_EMAIL = os.getenv("EMAIL_FROM", "admin@localhost")

# # Oidc
# OIDC_CLIENT_SECRETS = "client_secrets.json"
# OVERWRITE_REDIRECT_URI = os.getenv("OVERWRITE_REDIRECT_URI", None)
# OIDC_ID_TOKEN_COOKIE_SECURE = True
# OIDC_REQUIRE_VERIFIED_EMAIL = False
# OIDC_USER_INFO_ENABLED = True
# OIDC_OPENID_REALM = "master"
# OIDC_SCOPES = ["openid", "email", "profile"]
# OIDC_INTROSPECTION_AUTH_METHOD = "client_secret_post"



from flask import Blueprint, render_template, current_app, request, jsonify, session, flash, redirect, url_for, g
# from velero.auth import oidc

profile = Blueprint("dashboard", __name__)


@profile.route("/")
def index():
    return render_template("dashboard/index.html", page="dashboard")
